@@ -1,3 +1,3 @@
 from .simpful import FuzzySystem, LinguisticVariable, UndefinedUniverseOfDiscourseError
 from .rule_parsing import Clause, Functional, OR, AND, AND_p, NOT, preparse, postparse, find_index_operator, curparse
-from .fuzzy_sets import FuzzySet, MF_object, gaussian, Sigmoid_MF, InvSigmoid_MF, Gaussian_MF, InvGaussian_MF, DoubleGaussian_MF
+from .fuzzy_sets import FuzzySet, MF_object, gaussian, Sigmoid_MF, InvSigmoid_MF, Gaussian_MF, InvGaussian_MF, DoubleGaussian_MF, Triangular_MF, Trapezoidal_MF
\ No newline at end of file
